==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/GitHubIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitHubIdentityProviderFluent<A extends GitHubIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public GitHubIdentityProviderFluent.CaNested<A> withNewCa();
  public GitHubIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public GitHubIdentityProviderFluent.CaNested<A> editCa();
  public GitHubIdentityProviderFluent.CaNested<A> editOrNewCa();
  public GitHubIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getClientID();
  public A withClientID(String clientID);
  public Boolean hasClientID();
  
  /**
   * This method has been deprecated, please use method buildClientSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getClientSecret();
  public SecretNameReference buildClientSecret();
  public A withClientSecret(SecretNameReference clientSecret);
  public Boolean hasClientSecret();
  public A withNewClientSecret(String name);
  public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
  public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item);
  public GitHubIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
  public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
  public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item);
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  public A addToOrganizations(Integer index,String item);
  public A setToOrganizations(Integer index,String item);
  public A addToOrganizations(java.lang.String... items);
  public A addAllToOrganizations(Collection<String> items);
  public A removeFromOrganizations(java.lang.String... items);
  public A removeAllFromOrganizations(Collection<String> items);
  public List<String> getOrganizations();
  public String getOrganization(Integer index);
  public String getFirstOrganization();
  public String getLastOrganization();
  public String getMatchingOrganization(Predicate<String> predicate);
  public Boolean hasMatchingOrganization(Predicate<String> predicate);
  public A withOrganizations(List<String> organizations);
  public A withOrganizations(java.lang.String... organizations);
  public Boolean hasOrganizations();
  public A addToTeams(Integer index,String item);
  public A setToTeams(Integer index,String item);
  public A addToTeams(java.lang.String... items);
  public A addAllToTeams(Collection<String> items);
  public A removeFromTeams(java.lang.String... items);
  public A removeAllFromTeams(Collection<String> items);
  public List<String> getTeams();
  public String getTeam(Integer index);
  public String getFirstTeam();
  public String getLastTeam();
  public String getMatchingTeam(Predicate<String> predicate);
  public Boolean hasMatchingTeam(Predicate<String> predicate);
  public A withTeams(List<String> teams);
  public A withTeams(java.lang.String... teams);
  public Boolean hasTeams();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<GitHubIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface ClientSecretNested<N> extends Nested<N>,SecretNameReferenceFluent<GitHubIdentityProviderFluent.ClientSecretNested<N>>{
    public N and();
    public N endClientSecret();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/GitHubIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitHubIdentityProviderFluent<A extends GitHubIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public GitHubIdentityProviderFluent.CaNested<A> withNewCa();
  public GitHubIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public GitHubIdentityProviderFluent.CaNested<A> editCa();
  public GitHubIdentityProviderFluent.CaNested<A> editOrNewCa();
  public GitHubIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getClientID();
  public A withClientID(String clientID);
  public Boolean hasClientID();
  
  /**
   * This method has been deprecated, please use method buildClientSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getClientSecret();
  public SecretNameReference buildClientSecret();
  public A withClientSecret(SecretNameReference clientSecret);
  public Boolean hasClientSecret();
  public A withNewClientSecret(String name);
  public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecret();
  public GitHubIdentityProviderFluent.ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item);
  public GitHubIdentityProviderFluent.ClientSecretNested<A> editClientSecret();
  public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecret();
  public GitHubIdentityProviderFluent.ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item);
  public String getHostname();
  public A withHostname(String hostname);
  public Boolean hasHostname();
  public A addToOrganizations(int index,String item);
  public A setToOrganizations(int index,String item);
  public A addToOrganizations(java.lang.String... items);
  public A addAllToOrganizations(Collection<String> items);
  public A removeFromOrganizations(java.lang.String... items);
  public A removeAllFromOrganizations(Collection<String> items);
  public List<String> getOrganizations();
  public String getOrganization(int index);
  public String getFirstOrganization();
  public String getLastOrganization();
  public String getMatchingOrganization(Predicate<String> predicate);
  public Boolean hasMatchingOrganization(Predicate<String> predicate);
  public A withOrganizations(List<String> organizations);
  public A withOrganizations(java.lang.String... organizations);
  public Boolean hasOrganizations();
  public A addToTeams(int index,String item);
  public A setToTeams(int index,String item);
  public A addToTeams(java.lang.String... items);
  public A addAllToTeams(Collection<String> items);
  public A removeFromTeams(java.lang.String... items);
  public A removeAllFromTeams(Collection<String> items);
  public List<String> getTeams();
  public String getTeam(int index);
  public String getFirstTeam();
  public String getLastTeam();
  public String getMatchingTeam(Predicate<String> predicate);
  public Boolean hasMatchingTeam(Predicate<String> predicate);
  public A withTeams(List<String> teams);
  public A withTeams(java.lang.String... teams);
  public Boolean hasTeams();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<GitHubIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface ClientSecretNested<N> extends Nested<N>,SecretNameReferenceFluent<GitHubIdentityProviderFluent.ClientSecretNested<N>>{
    public N and();
    public N endClientSecret();
    
  }
  
}
